@@ -6,7 +6,6 @@ del get_versions
 
 ### Major classes
 from .time_series import TimeSeries
-from .processing_plan import ProcessingPlan
 from .periodogram import Periodogram
 from .metadata import Metadata
 from .candidate import Candidate
@@ -20,17 +19,18 @@ from .libffa import (
     ffafreq,
     ffaprd,
     generate_signal,
-    downsample
-    )
+    downsample,
+    boxcar_snr)
 
 from .peak_detection import find_peaks
 
 ### Serialization
 from .serialization import save_json, load_json
 
+from .tests import test
+
 __all__ = [
     'TimeSeries',
-    'ProcessingPlan',
     'Periodogram',
     'Metadata',
     'Candidate',
@@ -41,7 +41,9 @@ __all__ = [
     'ffaprd',
     'generate_signal',
     'downsample',
+    'boxcar_snr',
     'find_peaks',
     'save_json',
-    'load_json'
+    'load_json',
+    'test'
     ]
